@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 BEGIN {
-	our $VERSION = 'v0.1.1'; # VERSION
+	our $VERSION = 'v0.1.2'; # VERSION
 }
 
 use SOAP::Lite; # +trace => [ 'debug' ] ;
@@ -108,7 +108,7 @@ Business::CyberSource::Request::Authorization - CyberSource Authorization reques
 
 =head1 VERSION
 
-version v0.1.1
+version v0.1.2
 
 =head1 ATTRIBUTES
 
@@ -218,8 +218,6 @@ Reader: total
 
 Type: Num
 
-This attribute is required.
-
 =head2 cc_exp_month
 
 Reader: cc_exp_month
@@ -262,17 +260,23 @@ Type: Str
 
 This attribute is required.
 
-=head2 client_name
+=head2 foreign_currency
 
-Reader: client_name
+Reader: foreign_currency
+
+Type: Str
+
+=head2 reference_code
+
+Reader: reference_code
 
 Type: Str
 
 This attribute is required.
 
-=head2 reference_code
+=head2 client_name
 
-Reader: reference_code
+Reader: client_name
 
 Type: Str
 
@@ -386,6 +390,10 @@ Method originates in Business::CyberSource::Request::Authorization.
 
 Method originates in Business::CyberSource::Request::Authorization.
 
+=head2 foreign_currency
+
+Method originates in Business::CyberSource::Request::Authorization.
+
 =head2 client_version
 
 Method originates in Business::CyberSource::Request::Authorization.
